@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
-
-from admin_interface.compat import gettext_lazy as _
-from admin_interface.models import Theme
-
 from django.contrib import admin
+from django.utils.translation import gettext_lazy as _
+
+from admin_interface.models import Theme
 
 
 class ThemeAdmin(admin.ModelAdmin):
@@ -170,6 +168,16 @@ class ThemeAdmin(admin.ModelAdmin):
                 ),
             },
         ),
+        (
+            _("Change Form"),
+            {
+                "classes": ("wide",),
+                "fields": (
+                    "show_fieldsets_as_tabs",
+                    "show_inlines_as_tabs",
+                ),
+            },
+        ),
         (
             _("Recent Actions"),
             {"classes": ("wide",), "fields": ("recent_actions_visible",)},
