@@ -1,9 +1,6 @@
-# -*- coding: utf-8 -*-
-
 from __future__ import unicode_literals
 
-from admin_interface.compat import FileExtensionValidator
-
+from django.core.validators import FileExtensionValidator
 from django.db import migrations, models
 
 
